'use client'
import SendFile from "@/feature/messenger/components/ui/buttons/SendFile";
import { Button, Dropdown, DropdownItem, DropdownMenu, DropdownTrigger, Tooltip } from "@nextui-org/react";
import { Calendar, Image, Paperclip, Plus, User } from "react-feather";
import { useState, useEffect } from "react";
import useHandleConversationStore from "@/feature/messenger/store/useHandleConversationStore";
import { useTranslation } from "@/hooks/useTranslation";
import { LiaThumbtackSolid } from "react-icons/lia";
import { FaPlus } from "react-icons/fa6";
import useFastAnswerStore from "@/feature/messenger/store/useFastAnswerStore";
import usePermissionChat from "@/feature/messenger/hooks/usePermissionChat";

export default function OptionsButtonMobile() {
    // permisos Opciones
    const agentPermissions = usePermissionChat();
    const [components, setComponents] = useState<JSX.Element[]>([]);
    const handleOpenModalGallery = useHandleConversationStore(state => state.actions.handleOpenModalGallery);
    const handleOpenModalEditContact = useHandleConversationStore(state => state.actions.handleOpenModalEditContact);
    const handleOpenModalFollowUp = useHandleConversationStore(state => state.actions.handleOpenModalFollowUp);
    const setFastAnswerModal = useFastAnswerStore(state => state.setOpenModal);
    const { trans } = useTranslation();

    useEffect(() => {
        const componentOptions = () => {
            const componentsArray = [];

            if (agentPermissions.calendar) {
                componentsArray.push(
                    <DropdownItem
                        key="Seguimiento"
                        startContent={<Calendar size={20} />}
                        onClick={() => handleOpenModalFollowUp()}
                    >
                        Seguimiento
                    </DropdownItem>
                );
            }

            if (agentPermissions.biblioteca) {
                componentsArray.push(
                    <DropdownItem
                        key="Galeria"
                        startContent={<Image size={20} />}
                        onClick={() => handleOpenModalGallery()}
                    >
                        Galeria
                    </DropdownItem>
                );
            }

            if (agentPermissions.crea_agenda) {
                componentsArray.push(
                    <DropdownItem
                        key="Agenda"
                        startContent={<User size={20} />}
                        onClick={() => handleOpenModalEditContact()}
                    >
                        Agenda
                    </DropdownItem>
                );
            }

            if (agentPermissions.adjuntar_archivos) {
                componentsArray.push(
                    <DropdownItem
                        key="new"
                        startContent={<Paperclip size={20} />}
                    >
                        <SendFile />
                    </DropdownItem>
                );
            }

            componentsArray.push(
                <DropdownItem
                    key="new"
                    startContent={<LiaThumbtackSolid size={20} />}
                    onClick={() => setFastAnswerModal()}
                >
                    Respuesta Frecuente
                </DropdownItem>
            );

            return componentsArray;
        };

        setComponents(componentOptions());
    }, [agentPermissions]);

    return (
        <Dropdown placement="top" className={`${components.length === 0 ? "hidden" : "block"}`}>
            <Tooltip
                placement="top"
                content={trans('footer_content_chat_options_title')}
                color="default"
            >
                <div>
                    <DropdownTrigger>
                        <Button color="default" radius="full" className="text-gray-400 p-0 m-0 min-w-8 min-h-8 size-8 w-8 h-8" variant="light">
                            <FaPlus className='size-6' />
                        </Button>
                    </DropdownTrigger>
                </div>
            </Tooltip>
            <DropdownMenu aria-label="Dynamic Actions">
                {components}
            </DropdownMenu>
        </Dropdown>
    );
}
